[llvm-commits] CVS: llvm/include/llvm/Transforms/IPO.h

Misha Brukman brukman at cs.uiuc.edu
Thu Apr 22 18:00:02 PDT 2004


Changes in directory llvm/include/llvm/Transforms:

IPO.h updated: 1.31 -> 1.32

---
Log message:

Clarify the logic: the flag is renamed to `deleteFn' to signify it will delete
the function instead of isolating it. This also means the condition is reversed.


---
Diffs of the changes:  (+4 -4)

Index: llvm/include/llvm/Transforms/IPO.h
diff -u llvm/include/llvm/Transforms/IPO.h:1.31 llvm/include/llvm/Transforms/IPO.h:1.32
--- llvm/include/llvm/Transforms/IPO.h:1.31	Thu Apr 22 17:51:37 2004
+++ llvm/include/llvm/Transforms/IPO.h	Thu Apr 22 18:00:17 2004
@@ -66,11 +66,11 @@
 
 
 //===----------------------------------------------------------------------===//
 /// createFunctionExtractionPass - If isolateFn is true, this pass deletes as 
 /// much of the module as possible, except for the function specified.
 /// Otherwise, it deletes the given function, leaving everything else intact.
 ///
-Pass *createFunctionExtractionPass(Function *F, bool isolateFn = true);
+Pass *createFunctionExtractionPass(Function *F, bool deleteFn = false);
 
 
 //===----------------------------------------------------------------------===//
@@ -66,11 +66,11 @@
 
 //===----------------------------------------------------------------------===//
-/// createFunctionExtractionPass - If isolateFn is true, this pass deletes as 
-/// much of the module as possible, except for the function specified.
-/// Otherwise, it deletes the given function, leaving everything else intact.
+/// createFunctionExtractionPass - If deleteFn is true, this pass deletes as 
+/// the specified function. Otherwise, it deletes as much of the module as
+/// possible, except for the function specified.
 ///





More information about the llvm-commits mailing list